@@ -65,7 +65,6 @@ class AxiStreamHandler():
             try:
                 result = subprocess.check_output(['fp2bin', str(exponent_bits), str(mantissa_bits), str(num)],stderr=subprocess.DEVNULL)
                 bin_str = result.strip().decode()       # e.g. '010101...'
-                print(bin_str)
                 return int(bin_str, 2)
             except subprocess.CalledProcessError as e:
                 print("Error in subprocess: ", e)
@@ -89,11 +88,8 @@ class AxiStreamHandler():
                 convertedNumber = json.loads(xReq.text)["numbers"][0]
 
             except Exception as e:
-                print(e)
                 return 0
         
-        print("converted number: ", convertedNumber)
-
         return int(convertedNumber)
 
     def __cast_unsigned_to_bin(self, num, remote=False):
@@ -126,10 +122,6 @@ class AxiStreamHandler():
                 convertedNumber = xReq.read().replace("\n","")
                 return float(convertedNumber)
             else:
-
-                print("exponent bits: ", exponent_bits)
-                print("mantissa bits: ", mantissa_bits)
-
                 conversion_url ='http://127.0.0.1:80/bmnumbers'
 
                 tot_bit_len = exponent_bits + mantissa_bits + 3
@@ -137,14 +129,10 @@ class AxiStreamHandler():
                 strNum = "0b<"+str(tot_bit_len)+">"+str(num)
                 
                 newType = "flpe"+str(exponent_bits)+"f"+str(mantissa_bits)
-
-                print("new type: ", newType)
                 
                 reqBody = {'action': 'cast', 'numbers': [strNum], 'reqType': newType, 'viewMode': 'native'}
                 xReq = requests.post(conversion_url, json = reqBody)
                 
-                print("response: ", xReq.text)
-
                 convertedNumber = json.loads(xReq.text)["numbers"][0]
                 strNumber = convertedNumber[convertedNumber.rindex(">")+1:len(convertedNumber)]
                 return float(strNumber)
@@ -209,13 +197,12 @@ class AxiStreamHandler():
 
 
     def __init_channels(self):
-        print("Initializing channels")
         self.sendchannel = self.overlay.axi_dma_0.sendchannel
         self.recvchannel = self.overlay.axi_dma_0.recvchannel
 
     def __initialize_fixedpoint(self):
         self.total_bits = self.model_specs['register_size']  # Total number of bits
-        fractional_bits = int(self.model_specs['data_type'][6:7])  # Number of fractional bits
+        fractional_bits = int(self.model_specs['data_type'][6:len(self.model_specs['data_type'])])  # Number of fractional bits
         self.scale = 2 ** fractional_bits
 
     def __float_to_fixed(self, number):
@@ -255,6 +242,10 @@ class AxiStreamHandler():
             self.datatype = "np.float16"
         elif (self.model_specs["data_type"] == "float32"):
             self.datatype = "np.float32"
+        elif (self.model_specs["data_type"] == "fps16f10"):
+            self.datatype = "np.fps16f10"
+        elif (self.model_specs["data_type"] == "fps16f8"):
+            self.datatype = "np.fps16f8"
         elif (self.model_specs["data_type"] == "fps16f6"):
             self.datatype = "np.fps16f6"
         elif (self.model_specs["data_type"] == "fps32f16"):
@@ -270,6 +261,10 @@ class AxiStreamHandler():
             return np.float16, np.uint16
         elif (self.model_specs["data_type"] == "float32"):
             return np.float32, np.uint32
+        elif (self.model_specs["data_type"] == "fps16f10"):
+            return np.int16, np.int16
+        elif (self.model_specs["data_type"] == "fps16f8"):
+            return np.int16, np.int16
         elif (self.model_specs["data_type"] == "fps16f6"):
             return np.int16, np.int16
         elif (self.model_specs["data_type"] == "fps32f16"):
@@ -284,7 +279,7 @@ class AxiStreamHandler():
         else:
             raise Exception("Data type not supported yet")
 
-    def __parse_prediction(self, outputs):
+    def __parse_prediction(self, outputs, debug):
         # Stack all batches into one big (N, n_output) array
         stacked = np.vstack(outputs).astype(int)
         total_samples, n_out = stacked.shape
@@ -297,6 +292,7 @@ class AxiStreamHandler():
             clock_cycles = []
             data = stacked
 
+        all_probs = []
         # FPS branch: fixed‑point → float by scaling
         if self.model_specs["data_type"].startswith("fps"):
             # data is int array of shape (N, n_output)
@@ -304,13 +300,11 @@ class AxiStreamHandler():
             #probs = data.astype(np.float64) / self.scale
             #preds = np.argmax(probs, axis=1).astype(int).tolist()
             hw_classifications = []
-            print(len(outputs))
             for outcome in outputs:
                 for out in outcome:
                     probs = []
                     if self.model_specs["data_type"][:3] == "fps":
                         for i in range(0, self.n_output):
-                            print(out[i])
                             if self.benchcore == True and i == self.n_output - 1:
                                 clock_cycles.append(out[i])
                             else:
@@ -364,14 +358,20 @@ class AxiStreamHandler():
                             else:
                                 binary_str = bin(out[i])[2:].zfill(32)
                                 prob_float = self.__bin_to_float32(binary_str)
+
                                 probs.append(prob_float)
-            
+
+                    
+                    all_probs.append(probs)
                     classification = np.argmax(probs)
                     hw_classifications.append(int(classification))
             
+            
             preds = hw_classifications
 
-        return {'predictions': preds, 'clock_cycles': clock_cycles}
+        
+
+        return {'predictions': preds, 'clock_cycles': clock_cycles, 'all_probs': all_probs}
     def release(self):
         self.overlay.free()
         if getattr(self, "_flp_pool", None):
@@ -389,17 +389,17 @@ class AxiStreamHandler():
 
             for i in range(0, len(self.batches)):
                 input_buffer[:]=self.batches[i]
-                print("input buffer: ", input_buffer)
+                #print("input buffer: ", input_buffer)
                 output_buffer = allocate(shape=self.output_shape, dtype=data_type_output)
                 if debug:
                     start_time = time.time()
-                print("Before transfer")
+                #print("Before transfer")
                 self.sendchannel.transfer(input_buffer)
                 self.recvchannel.transfer(output_buffer)
                 self.sendchannel.wait()
                 self.recvchannel.wait()
-                print("After transfer")
-                print("output buffer: ", output_buffer)
+                #print("After transfer")
+                #print("output buffer: ", output_buffer)
                 if debug:
                     end_time = time.time()
                     time_diff = (end_time - start_time) * 1000
@@ -444,14 +444,14 @@ class AxiStreamHandler():
                     else:
                         outputs.append(output_buffer)
 
-            print(outputs)
+            #print(outputs)
             if debug:
                 print("Time taken to predict a batch of size ", self.batch_size, " is ", np.mean(latencies), " ms")
                 print("Time taken to predict a single sample is ", np.mean(latencies)/self.batch_size, " ms")
                 print("Standard deviation of the time taken to predict a batch of size ", self.batch_size, " is ", np.std(latencies), " ms")
                 print("Standard deviation of the time taken to predict a single sample is ", np.std(latencies)/self.batch_size, " ms")
                 
-        result = self.__parse_prediction(outputs)
+        result = self.__parse_prediction(outputs, debug)
 
         del input_buffer
         del output_buffer
